@@ -19,10 +19,12 @@ from selenium.webdriver.remote.command import Command as RemoteCommand
 from selenium.webdriver.remote.webelement import WebElement as SeleniumWebElement
 from typing_extensions import Self
 
+from appium.protocols.webdriver.can_find_elements import CanFindElements
+
 from .mobilecommand import MobileCommand as Command
 
 
-class WebElement(SeleniumWebElement):
+class WebElement(SeleniumWebElement, CanFindElements):
     _execute: Callable
     _id: str
 
@@ -88,7 +90,7 @@ class WebElement(SeleniumWebElement):
         """
 
         # NOTE: this method is overridden because the selenium client returned None instead of self.
-        # Appium python cleint would like to allow users to chain methods.
+        # Appium python client would like to allow users to chain methods.
         data = {'id': self.id}
         self._execute(Command.CLEAR, data)
         return self
